==> copernicus_marine_client-0.10.2-py3-none-any.whl: copernicus_marine_client/python_interface/load_utils.py <==
from typing import Callable, Union

import pandas
import xarray

from copernicus_marine_client.catalogue_parser.catalogue_parser import (
    CopernicusMarineDatasetServiceType,
    parse_catalogue,
)
from copernicus_marine_client.catalogue_parser.request_structure import (
    LoadRequest,
)
from copernicus_marine_client.core_functions.credentials_utils import (
    get_username_password,
)
from copernicus_marine_client.core_functions.services_utils import (
    CommandType,
    RetrievalService,
    get_retrieval_service,
)
from copernicus_marine_client.core_functions.utils import (
    ServiceNotSupported,
    delete_cache_folder,
)


def load_data_object_from_load_request(
    load_request: LoadRequest,
    disable_progress_bar: bool,
    arco_series_load_function: Callable,
    opendap_load_function: Callable,
) -> Union[xarray.Dataset, pandas.DataFrame]:
    if load_request.overwrite_metadata_cache:
        delete_cache_folder()

    catalogue = parse_catalogue(
        no_metadata_cache=load_request.no_metadata_cache,
        disable_progress_bar=disable_progress_bar,
    )
    retrieval_service: RetrievalService = get_retrieval_service(
        catalogue=catalogue,
        dataset_id=load_request.dataset_id,
        dataset_url=load_request.dataset_url,
        force_dataset_version_label=load_request.force_dataset_version,
        force_dataset_part_label=None,
        force_service_type_string=load_request.force_service,
        command_type=CommandType.LOAD,
        dataset_subset=load_request.get_time_and_geographical_subset(),
    )
    username, password = get_username_password(
        load_request.username,
        load_request.password,
        load_request.credentials_file,
    )
    load_request.dataset_url = retrieval_service.uri
    if retrieval_service.service_type in [
        CopernicusMarineDatasetServiceType.GEOSERIES,
        CopernicusMarineDatasetServiceType.TIMESERIES,
    ]:
        dataset = arco_series_load_function(
            username=username,
            password=password,
            dataset_url=load_request.dataset_url,
            variables=load_request.variables,
            geographical_parameters=load_request.geographical_parameters,
            temporal_parameters=load_request.temporal_parameters,
            depth_parameters=load_request.depth_parameters,
            chunks=None,
        )
    elif (
        retrieval_service.service_type
        == CopernicusMarineDatasetServiceType.OPENDAP
    ):
        dataset, _ = opendap_load_function(
            username=username,
            password=password,
            dataset_url=load_request.dataset_url,
            variables=load_request.variables,
            geographical_parameters=load_request.geographical_parameters,
            temporal_parameters=load_request.temporal_parameters,
            depth_parameters=load_request.depth_parameters,
        )
    else:
        raise ServiceNotSupported(retrieval_service.service_type)
    return dataset

==> copernicus_marine_client-0.10.7-py3-none-any.whl: copernicus_marine_client/python_interface/load_utils.py <==
from typing import Callable, Union

import pandas
import xarray

from copernicus_marine_client.catalogue_parser.catalogue_parser import (
    CopernicusMarineDatasetServiceType,
    parse_catalogue,
)
from copernicus_marine_client.catalogue_parser.request_structure import (
    LoadRequest,
)
from copernicus_marine_client.core_functions.credentials_utils import (
    get_username_password,
)
from copernicus_marine_client.core_functions.services_utils import (
    CommandType,
    RetrievalService,
    get_retrieval_service,
)
from copernicus_marine_client.core_functions.utils import (
    ServiceNotSupported,
    delete_cache_folder,
)
from copernicus_marine_client.download_functions.subset_xarray import (
    check_dataset_subset_bounds,
)


def load_data_object_from_load_request(
    load_request: LoadRequest,
    disable_progress_bar: bool,
    arco_series_load_function: Callable,
    opendap_load_function: Callable,
) -> Union[xarray.Dataset, pandas.DataFrame]:
    if load_request.overwrite_metadata_cache:
        delete_cache_folder()

    catalogue = parse_catalogue(
        no_metadata_cache=load_request.no_metadata_cache,
        disable_progress_bar=disable_progress_bar,
    )
    retrieval_service: RetrievalService = get_retrieval_service(
        catalogue=catalogue,
        dataset_id=load_request.dataset_id,
        dataset_url=load_request.dataset_url,
        force_dataset_version_label=load_request.force_dataset_version,
        force_dataset_part_label=load_request.force_dataset_part,
        force_service_type_string=load_request.force_service,
        command_type=CommandType.LOAD,
        dataset_subset=load_request.get_time_and_geographical_subset(),
    )
    username, password = get_username_password(
        load_request.username,
        load_request.password,
        load_request.credentials_file,
    )
    load_request.dataset_url = retrieval_service.uri
    check_dataset_subset_bounds(
        username=username,
        password=password,
        dataset_url=load_request.dataset_url,
        service_type=retrieval_service.service_type,
        dataset_subset=load_request.get_time_and_geographical_subset(),
        subset_method=load_request.subset_method,
    )
    if retrieval_service.service_type in [
        CopernicusMarineDatasetServiceType.GEOSERIES,
        CopernicusMarineDatasetServiceType.TIMESERIES,
        CopernicusMarineDatasetServiceType.OMI_ARCO,
        CopernicusMarineDatasetServiceType.STATIC_ARCO,
    ]:
        dataset = arco_series_load_function(
            username=username,
            password=password,
            dataset_url=load_request.dataset_url,
            variables=load_request.variables,
            geographical_parameters=load_request.geographical_parameters,
            temporal_parameters=load_request.temporal_parameters,
            depth_parameters=load_request.depth_parameters,
            chunks=None,
        )
    elif (
        retrieval_service.service_type
        == CopernicusMarineDatasetServiceType.OPENDAP
    ):
        dataset, _ = opendap_load_function(
            username=username,
            password=password,
            dataset_url=load_request.dataset_url,
            variables=load_request.variables,
            geographical_parameters=load_request.geographical_parameters,
            temporal_parameters=load_request.temporal_parameters,
            depth_parameters=load_request.depth_parameters,
        )
    else:
        raise ServiceNotSupported(retrieval_service.service_type)
    return dataset
